aboutsummaryrefslogtreecommitdiff
path: root/model.h
diff options
context:
space:
mode:
Diffstat (limited to 'model.h')
-rw-r--r--model.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/model.h b/model.h
index be4da2b..dfbca59 100644
--- a/model.h
+++ b/model.h
@@ -22,7 +22,7 @@ const int CLS_REPR_CONS = 1 << 3;
const int CLS_REPR_STR = 1 << 4;
const int CLS_SIM_OBJ = 1 << 0;
-const int CLS_CONS_OBJ = 1 << 1;
+const int CLS_PAIR_OBJ = 1 << 1;
const int CLS_OPT_OBJ = 1 << 3;
@@ -84,7 +84,7 @@ class EvalObj : public FrameObj {
public:
/**
* Construct an EvalObj
* @param otype the type of the EvalObj (CLS_CONS_OBJ for a
* construction, CLS_SIM_OBJ for a simple object), which defaults to
* CLS_SIM_OBJ
*/
@@ -84,7 +84,7 @@ class EvalObj : public FrameObj {
/**
* Construct an EvalObj
- * @param otype the type of the EvalObj (CLS_CONS_OBJ for a
+ * @param otype the type of the EvalObj (CLS_PAIR_OBJ for a
* construction, CLS_SIM_OBJ for a simple object), which defaults to
* CLS_SIM_OBJ